@@ -696,6 +696,8 @@ def load_and_process_image_deepface(image_input, country=None):
                 del processed_image, image_rgb
                 if 'face_objs' in locals():
                     del face_objs
+        if country=='QAT':
+            return 0,0
 
         # Try other angles in parallel
         angles = [90, 180, 270]
@@ -1058,92 +1060,4 @@ def extract_face_and_compute_cosine_similarity(selfie, front_face_locations, fro
             print(f"Error in extract_face_and_compute_similarity: {e}")
             import traceback
             traceback.print_exc()
-            return 0
-
-def load_and_process_image_deepface_serial(image_input, country=None):
-    """
-    Like load_and_process_image_deepface, but processes angles sequentially (0, 90, 180, 270).
-    Returns face_locations, face_encodings if found, else empty lists.
-    """
-    DeepFace = get_deepface()  # Only load when needed
-    face_recognition = get_face_recognition()  # Only load when needed
-    def process_angle(img, angle):
-        try:
-            if angle != 0:
-                with np.errstate(all='ignore'):
-                    img_rgb = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
-                    img_pil = Image.fromarray(img_rgb)
-                    rotated = np.ascontiguousarray(img_pil.rotate(angle, expand=True))
-                    img_to_process = cv2.cvtColor(rotated, cv2.COLOR_RGB2BGR)
-                    del img_rgb, img_pil, rotated
-            else:
-                img_to_process = img
-            face_objs = DeepFace.extract_faces(
-                img_to_process,
-                detector_backend='fastmtcnn',
-                enforce_detection=False,
-                align=True
-            )
-            if face_objs and len(face_objs) > 0:
-                confidence = face_objs[0].get('confidence', 0)
-                if confidence < 1:
-                    facial_area = face_objs[0]['facial_area']
-                    if country == 'SDN' and (facial_area['w'] < 40 or facial_area['h'] < 50):
-                        return None, None, 0
-                    elif country != 'SDN' and (facial_area['w'] < 80 or facial_area['h'] < 90):
-                        return None, None, 0
-                if confidence < 0.95:
-                    return None, None, 0
-                return face_objs, img_to_process, confidence
-            del img_to_process
-            return None, None, 0
-        except Exception as e:
-            return None, None, 0
-        finally:
-            if 'img_to_process' in locals():
-                del img_to_process
-    try:
-        if isinstance(image_input, np.ndarray):
-            image = np.ascontiguousarray(image_input)
-            if image.dtype != np.uint8:
-                image = image.astype(np.uint8, copy=False)
-        elif isinstance(image_input, str):
-            image_data = base64.b64decode(image_input)
-            image = cv2.imdecode(np.frombuffer(image_data, np.uint8), cv2.IMREAD_COLOR)
-            del image_data
-        else:
-            return [], []
-        if image is None or image.size == 0:
-            return [], []
-        CONFIDENCE_THRESHOLD = 0.97
-        angles = [0, 90, 180, 270]
-        for angle in angles:
-            face_objs, processed_image, confidence = process_angle(image, angle)
-            if face_objs is not None and confidence >= CONFIDENCE_THRESHOLD:
-                try:
-                    biggest_face = max(face_objs, key=lambda face: face['facial_area']['w'] * face['facial_area']['h'])
-                    facial_area = biggest_face['facial_area']
-                    if confidence < 1:
-                        if country == 'SDN' and (facial_area['w'] < 40 or facial_area['h'] < 50):
-                            return [], []
-                        elif country != 'SDN' and (facial_area['w'] < 80 or facial_area['h'] < 90):
-                            return [], []
-                    x, y, w, h = facial_area['x'], facial_area['y'], facial_area['w'], facial_area['h']
-                    image_rgb = cv2.cvtColor(processed_image, cv2.COLOR_BGR2RGB)
-                    face_locations = [(y, x + w, y + h, x)]
-                    face_encodings = face_recognition.face_encodings(image_rgb, face_locations)
-                    if face_encodings:
-                        return face_locations, face_encodings
-                finally:
-                    if 'processed_image' in locals():
-                        del processed_image
-                    if 'image_rgb' in locals():
-                        del image_rgb
-                    if 'face_objs' in locals():
-                        del face_objs
-        return [], []
-    except Exception as e:
-        return [], []
-    finally:
-        if 'image' in locals():
-            del image
+            return 0
\ No newline at end of file
