@@ -215,7 +215,6 @@ def convert_dob_to_standard(date_str):
     for fmt in input_formats:
         try:
             parsed_date = datetime.strptime(date_str, fmt)
-            #return parsed_date.strftime("%Y-%m-%d")
             return parsed_date.strftime("%d/%m/%Y")
         except ValueError:
             continue
@@ -295,4 +294,4 @@ def normalise_dates_for_nfc(date_str):
         dt = datetime.strptime(date_str, "%Y/%m/%d")
         return dt.strftime("%d/%m/%Y")
     except Exception:
-        return date_str  # Return as is if format is incorrect
+        raise ValueError("Input date must be in 'YYYY/MM/DD' format.")
