@@ -120,9 +120,12 @@ def sanity_check_irq_passport(full_name='',
         # Reuse expiry_date for datetime object temporarily for calculations
         expiry_date_obj = datetime.strptime(expiry_date, "%Y-%m-%d")
         issue_date = (expiry_date_obj - relativedelta(years=8) + timedelta(days=1)).strftime("%Y-%m-%d")
+        try:
+            dob = sanity_utils.convert_dob_to_standard(dob)
+            expiry_date = sanity_utils.convert_dob_to_standard(expiry_date)
+        except Exception as e:
+            return {"error": "covered_photo", "error_details": "Exception Thrown while parsing dates: {e}"}
 
-        dob = sanity_utils.convert_dob_to_standard(dob)
-        expiry_date = sanity_utils.convert_dob_to_standard(expiry_date)
 
 
         if gender_letter.lower() not in ['m','f','male','female']:
@@ -375,9 +378,15 @@ def sanity_check_irq_back(
                 'error': 'covered_photo',
                 'error_details': f'Missing or empty fields: {", ".join(missing)}'
             }
+        try:
+            dob = sanity_utils.convert_dob_to_standard(dob)
+            expiry_date = sanity_utils.convert_dob_to_standard(expiry_date)
+        except Exception as e:
+            return {
+                'error': 'covered_photo',
+                'error_details': f'Exception Thrown while parsing dates: {e}'
+            }
 
-        dob = sanity_utils.normalise_dates_for_nfc(dob)
-        expiry_date = sanity_utils.normalise_dates_for_nfc(expiry_date)
 
         result =  {
             "error": "",
