@@ -705,6 +705,12 @@ def data_consistency_check(data, front_id_text, back_id_text, country, back_img)
         else:
             data_consistency['breakdown']['document_type']['result'] = 'consider'
 
+        if data.get('id_number_front', '') and data.get('id_number', ''):
+            if data.get('id_number_front', '') != data.get('id_number', ''):
+                data_consistency['breakdown']['multiple_data_sources_present']['result'] = 'consider'
+
+
+
     if country == 'SAU':
         doc_type1 = identify_front_id(front_id_text)
         if doc_type1:
@@ -1708,10 +1714,15 @@ def form_final_data_document_report(data, front_id_text, back_id_text, country,
 
         #For ATA Testing phase
         if country == 'UAE':
-            keys_to_mark = ['original_document_present','conclusive_document_quality','image_quality','data_consistency', 'data_comparison', 'image_integrity', 'data_validation', 'visual_authenticity']
-            document_report = mark_clear(document_report, keys_to_mark)
-            document_report['result'] = 'clear'
-            document_report['sub_result'] = 'clear'
+
+            if document_report['breakdown']['data_consistency']['breakdown']['multiple_data_sources_present']['result'] == 'consider':
+                document_report['result'] = 'consider'
+                document_report['sub_result'] = 'caution'
+            else:
+                keys_to_mark = ['original_document_present','conclusive_document_quality','image_quality','data_consistency', 'data_comparison', 'image_integrity', 'data_validation', 'visual_authenticity']
+                document_report = mark_clear(document_report, keys_to_mark)
+                document_report['result'] = 'clear'
+                document_report['sub_result'] = 'clear'
 
         if country == 'QAT' and(document_report['breakdown']['visual_authenticity']['result'] == 'clear' and document_report['breakdown']['visual_authenticity']['breakdown']['face_detection'] == 'clear' and document_report['breakdown']['data_consistency']['breakdown']['multiple_data_sources_present']['result'] == 'clear'):
             keys_to_mark = ['data_consistency', 'data_comparison', 'image_integrity', 'data_validation', 'visual_authenticity']
