@@ -647,8 +647,6 @@ def qatar_front_id_extraction(client, image_data, front_id_text, front_id_text_d
             return {'error':'dob_glare'}
 
         age_check_2 = is_age_18_above(result.get('dob', ''))
-        if not age_check_2:
-            return {'error': 'under_age'}
         if age_check_2=='invalid_format':
             return {'error':'dob_glare'}
 
