@@ -353,7 +353,7 @@ def sdn_passport_extraction(passport_text):
         if len(sorted_date_strings)>1:
             dob = sorted_date_strings[0].replace('-', '/')
             issue_date = sorted_date_strings[1].replace('-', '/')
-            expiry = sorted_date_strings[-1].replace('-', '/')
+            expiry = sorted_date_strings[2].replace('-', '/')
         
         else:
             matches = re.findall(r'\d{2}-\d{2}-\d{4}', passport_text)
@@ -366,7 +366,7 @@ def sdn_passport_extraction(passport_text):
             if sorted_date_strings:
                 dob = sorted_date_strings[0].replace('-', '/')
                 issue_date = sorted_date_strings[1].replace('-', '/')
-                expiry = sorted_date_strings[-1].replace('-', '/')
+                expiry = sorted_date_strings[2].replace('-', '/')
        
     except:
         dob, issue_date, expiry = '', '', ''
@@ -852,6 +852,8 @@ def extract_passport_details_genai(passport_data):
         Make sure to extract the correct names from both Arabic and English text. 
         Important NOTE: If the number of words in name_en and name_ar are not equal, translate the English name (name_en) into Arabic and update name_ar with the translated text.
         
+        Make sure issue date and expiry dates are either 5 years or 10 years apart.
+        
         The MRZ lines should be complete.
         The response should only contain a dictionary with these fields.
 
